import { Component } from 'react'
import { View, Text, Button, Image, scrollView, Input } from '@tarojs/components'
import * as api from '../../service/index'
import tool from '../../common/tool'
import Taro, { } from '@tarojs/taro'
import './index.less'

export default class collection extends Component {
  state = {
    bookList: [],
    isEdit: false,
    isOverSelect: false
  }

  componentWillMount () {
  }
  componentDidShow () {
    Taro.showLoading({
      title: '加载中',
    })
    if (!Taro.getStorageSync('session_key')) {
      setTimeout(() => {
        this.myBookFollow()
      }, 1000)
    } else {
      this.myBookFollow()
    }
  }
  myBookFollow () {
    api.myBookFollow().then(res => {
      Taro.hideLoading()
      if (res.code == 200) {
        this.setState({
          bookList: res.data
        })
      }
    })
  }
  changeEdit () {
    this.setState({
      isEdit: true
    })
  }
  cancelEdit () {
    let _bookList = this.state.bookList
    _bookList.forEach((item, index) => {
      item.isSelect = false
    })
    this.setState({
      bookList: _bookList,
      isOverSelect: false,
      isEdit: false
    })
  }
  deleteEdit () {
    let that = this
    Taro.showModal({
      title: '提示',
      content: '确定删除吗？',
      success: function (res) {
        if (res.confirm) {
          let book_ids = []
          that.state.bookList.forEach(item => {
            if (item.isSelect) {
              book_ids.push(item.book_id)
            }
          })
          api.deleteBookCollect({ book_ids: book_ids.toString() }).then(res => {
            if (res.code == 200) {
              that.myBookFollow()
              that.setState({
                isEdit: false,
                isOverSelect: false
              })
            }
          })
        } else if (res.cancel) {
          console.log('用户点击取消')
        }

      }
    })



  }
  overSelect () {
    let _bookList = this.state.bookList
    _bookList.forEach((item, index) => {
      item.isSelect = !this.state.isOverSelect
    })
    this.setState({
      bookList: _bookList,
      isOverSelect: !this.state.isOverSelect,
    })
  }
  changeSelect (item, index) {
    console.log(item);
    if (!this.state.isEdit) {
      Taro.navigateTo({
        url: `/pages/index/subpages/novelText/index?book_id=${item.book_id}`
      })
    } else {
      let _bookList = this.state.bookList
      _bookList.forEach((item, i) => {
        if (index == i) {
          item.isSelect = !this.state.bookList[index].isSelect
        }
      })

      this.setState({
        bookList: _bookList
      }, () => {
        let list = this.state.bookList.filter(res => {
          return !res.isSelect
        })
        if (list.length == 0) {
          this.setState({
            isOverSelect: true
          })
        } else {
          this.setState({
            isOverSelect: false
          })
        }
      })
    }
  }
  addBooks () {
    Taro.navigateTo({
      url: '/pages/index/subpages/search/index'
    })
  }

  render () {
    return (
      <View className='mine'>
        {
          this.state.bookList.length == 0 ?
            <View className='empty'>
              <Image className='empty-img' src='https://video-img.fyshark.com/1683801289275slsll.png'></Image>
              <View className='empty-tips'>书架暂时没有书哦！</View>
              <View className='add' onClick={e => (this.addBooks())}>去添加</View>
            </View>
            :
            <View>

              {
                !this.state.isEdit ?
                  <View className='edit'>
                    <View className='edit-content' onClick={e => (this.changeEdit())}>

                      <Image className='edit-img' src='https://video-img.fyshark.com/1683687193883dhksjn.png'></Image>
                      编辑
                    </View>
                  </View>
                  :
                  <View className='select'>
                    <View className='select-content' onClick={e => (this.overSelect())}>
                      <Image className='select-img' src={this.state.isOverSelect ? 'https://video-img.fyshark.com/1683698925516hnakjl.png' : 'https://video-img.fyshark.com/1683698074122dhkahj.png'}></Image>
                      全选
                    </View>
                  </View>
              }
              <View className='content'>
                {
                  this.state.bookList.map((item, index) => (
                    <View className='content-info' key={index} onClick={e => (this.changeSelect(item, index))}>
                      <View className='info-image'>
                        <Image className='info-img' mode='widthFix' src={item.img}></Image>
                        {
                          this.state.isEdit &&
                          <Image className='select-icon' src={item.isSelect ? 'https://video-img.fyshark.com/1683699004116sihel.png' : 'https://video-img.fyshark.com/1683698064582dhka.png'}></Image>
                        }
                      </View>
                      <View className='info-title'>{tool.ellipsis(item.name, 6)}</View>
                      <View className='info-tips'>已读{item.read_cnt}章·更新{item.album_cnt}章</View>
                    </View>
                  ))
                }
              </View>
              {
                this.state.isEdit &&
                <View className='edit-console'>
                  <View className='console'>
                    <View className='cancellation' onClick={e => (this.cancelEdit())}>取消</View>
                    <View className='delete' onClick={e => (this.deleteEdit())}>删除</View>
                  </View>
                </View>
              }
            </View>
        }
      </View>
    )
  }
}
