import { Component } from 'react'
import { View, Text, Button, Image, scrollView, RichText, Input } from '@tarojs/components'
import * as api from '../../../../service/index'
import tool from '../../../../common/tool'
import Taro, { getCurrentInstance } from '@tarojs/taro'
import './index.less'
import { AtDrawer } from 'taro-ui'
import "taro-ui/dist/style/components/drawer.scss";

export default class collection extends Component {
  $instance = getCurrentInstance()
  state = {
    booksinfo: {},
    directoryList: [],//目录
    show: false,
    order_by_sta: 0,//0:正序，1:倒序
    content_id: 0,//上次观看的章节
    isConsole: true,
    purchaseList: [
      {
        title: '7天包周',
        money: 990,
        oldMoney: '￥19.8元/周',
        tips: '热门',
        text: '立享5折',
      },
      {
        title: '7天包周',
        money: 990,
        oldMoney: '￥19.8元/周',
        tips: '',
        text: '立享5折',
      },
      {
        title: '7天包周',
        money: 990,
        oldMoney: '￥19.8元/周',
        tips: '优惠',
        text: '立享5折',
      },
    ],
    selectVip: 0,//当前选择的充值
    isIos: false,
    pay_status: 1,//是否绑定口令
    code: '',
    isOpendDrectory: false,//是否打开目录
  }

  componentWillMount () {
    if (!Taro.getStorageSync('session_key')) {
      setTimeout(() => {
        this.getBookCatalogue()
        this.getShopList()
      }, 1500)
    } else {
      this.getBookCatalogue()
      this.getShopList()
      this.getAppConfig()
    }
    let that = this
    Taro.getSystemInfo({
      success: function (res) {
        if (res.platform != "android") {
          that.setState({
            isIos: true
          })
        }
      }
    })
  }
  componentDidShow () {
  }
  getAppConfig () {
    api.getAppConfig().then(res => {
      if (res.code == 200) {
        this.setState({
          isOpendDrectory: res.data.status_chapter == 0 ? false : true
        })
      }
    })
  }
  getBookCatalogue () {
    Taro.showLoading({
      title: '加载中',
    })
    let routers = this.$instance.router.params

    api.getBookCatalogue({ book_id: routers.book_id, order_by_sta: this.state.order_by_sta }).then(res => {
      Taro.hideLoading()
      if (res.code == 200) {
        this.setState({
          directoryList: res.data.book_catalogue,
          content_id: res.data.content_id
        }, () => {
          this.getBookContent()
        })
      }
    })
  }

  getBookContent () {
    let that = this
    let routers = this.$instance.router.params
    api.getBookContent({ book_id: routers.book_id, content_id: this.state.content_id }).then(res => {
      if (res.code == 200) {
        Taro.setNavigationBarTitle({ title: res.data.title })
        this.setState({
          booksinfo: res.data
        }, () => {
          that.changeChapter(res.data.content_id)
          Taro.pageScrollTo({
            scrollTop: 0,
            duration: 10
          })
        })
      }
    })
  }
  changeOrderBySta () {
    this.setState({
      order_by_sta: this.state.order_by_sta == 0 ? 1 : 0
    }, () => {
      this.getBookCatalogue()
    })
  }
  getShopList () {
    api.getShopList().then(res => {
      if (res.code == 200) {
        this.setState({
          purchaseList: res.data.vip_list,
          pay_status: res.data.pay_status
        })
      }
    })
  }
  //充值
  toOrder () {
    if (this.state.purchaseList[this.state.selectVip].ios_status == 0) {
      if (this.state.isIos) {
        Taro.showToast({
          title: 'ios暂不支持充值',
          icon: 'none',
          duration: 2000
        })
        return
      }
    }
    let that = this
    let item = this.state.purchaseList[this.state.selectVip]
    if (process.env.TARO_ENV === 'tt') {
      Taro.showLoading({
        title: '加载中...',
      })
      let routers = this.$instance.router.params
      api.ttCreateOrder({ pay_info_id: item.id, book_id: routers.book_id }).then(res => {
        if (res.code == 200) {
          Taro.hideLoading()
          tt.pay({
            orderInfo: {
              order_id: res.data.order_id,
              order_token: res.data.order_token
            },
            service: 5,
            success (item) {
              if (item.code == 0) {
                that.getBookCatalogue()
                that.getShopList()
                setTimeout(() => {
                  that.getBookCatalogue()
                  that.getShopList()
                }, 2000);
                // 支付成功处理逻辑，只有res.code=0时，才表示支付成功
                // 但是最终状态要以商户后端结果为准
              }
            },
            fail (item) {
              // 调起收银台失败处理逻辑
            },
          });
        }
      })
    } else if (process.env.TARO_ENV === 'weapp') {
      Taro.getSystemInfo({
        success: function (res) {
          Taro.showLoading({
            title: '加载中...',
          })
          api.createOrder({ shop_id: item.id }).then(res => {
            if (res.code == 200) {
              Taro.hideLoading()
              Taro.requestPayment({
                timeStamp: res.data.timeStamp,
                nonceStr: res.data.nonceStr,
                package: res.data.package,
                signType: res.data.signType,
                paySign: res.data.paySign,
                success: function (res) {
                  that.getBookCatalogue()
                  that.getShopList()
                  setTimeout(() => {
                    that.getBookCatalogue()
                    that.getShopList()
                  }, 2000);
                },
                fail: function (err) {
                  try {
                    const res = Taro.getSystemInfoSync()
                    console.log(res, 'iphone=====');
                  } catch (e) {
                  }
                }
              })
            }
          })
        }
      })
    }

  }
  selectVip (item, index) {
    this.setState({
      selectVip: index
    })
  }
  //上一章
  previous () {
    if (this.state.booksinfo.content_last_id == 0) return
    this.setState({
      content_id: this.state.booksinfo.content_last_id
    }, () => {

      // this.changeChapter(this.state.booksinfo.content_last_id)
      this.getBookContent()
    })
  }
  //打开目录
  directory () {
    this.setState({
      show: true
    })
  }
  unDirectory () {
    this.setState({
      show: false
    })
  }
  //下一章
  next () {
    if (this.state.booksinfo.content_next_id == 0) return
    this.setState({
      content_id: this.state.booksinfo.content_next_id
    }, () => {
      // this.changeChapter(this.state.booksinfo.content_next_id)
      this.getBookContent()
    })
  }
  //上报阅读记录
  changeChapter (content_id) {
    api.bookReadReort({ content_id: content_id }).then(res => {
      if (res.code == 200) {

      }
    })
  }
  jumpChapter (content_id) {
    this.setState({
      show: false,
      content_id: content_id
    }, () => {
      this.getBookContent()
    })
  }
  changeIsConsole () {
    this.setState({
      isConsole: !this.state.isConsole
    })
  }
  openCode () {
    this.setState({
      isOpen: true
    })
  }
  searchCode (e) {
    this.setState(
      {
        code: e.detail.value
      }
    )
  }
  cancel () {
    this.setState({
      isOpen: false
    })
  }
  determine () {
    api.getCheckoutBookCode({ input_str: this.state.code }).then(res => {
      if (res.code == 200) {
        this.getShopList()
        this.setState({
          isOpen: false
        })
        Taro.showToast({
          title: `已获取折扣`,
          icon: 'none',
          duration: 2000
        })
      } else {
        Taro.showToast({
          title: res.msg,
          icon: 'none',
          duration: 2000
        })
      }
    })
  }

  render () {
    return (
      <View className='mine'>

        {
          this.state.booksinfo.book_is_vip == 0 &&
          <View className='mine-content'>
            <View className='console-modil' onClick={e => (this.changeIsConsole())}>
            </View>
            <View className='novel-title'>{this.state.booksinfo.book_name}</View>
            <RichText
              className='member-title'
              nodes={this.state.booksinfo.book_content}></RichText>
            {
              this.state.isConsole &&
              <View className='console'>
                <View className='console-deteal'>
                  <View className='console-left' style={this.state.booksinfo.content_last_id == 0 ? 'opacity: 0.3;' : ''} onClick={e => (this.previous())}>
                    <Image className='console-img' src='https://video-img.fyshark.com/1683623105394hsikah.png'></Image>
                    上一章
                  </View>
                  {
                    this.state.isOpendDrectory &&
                    <View className='console-content' onClick={e => (this.directory())}>
                      <Image className='console-img' src='https://video-img.fyshark.com/1683623271853dhjkdhjl.png'></Image>
                      目录
                    </View>
                  }
                  <View className='console-right' style={this.state.booksinfo.content_next_id == 0 ? 'opacity: 0.3;' : ''} onClick={e => (this.next())}>
                    下一章
                    <Image className='console-img' src='https://video-img.fyshark.com/1683623282017shiojh.png'></Image>
                  </View>
                </View>
              </View>
            }
            <AtDrawer
              show={this.state.show}
              className='drawer'
              onClose={e => (this.unDirectory())}
              left
              width='300px'
              mask
            >
              <View className='drawer-content'>
                <View className='drawer-over'>
                  <View className='drawer-over-num'>共{this.state.directoryList.length}章</View>
                  <View className='drawer-over-right' onClick={e => (this.changeOrderBySta())}>
                    <View className='drawer-over-right-title'>倒序</View>
                    <Image className='drawer-over-right-img' src='https://video-img.fyshark.com/1683631467893djaj.png'></Image>
                  </View>
                </View>
                <View className='drawer-list'>
                  {
                    this.state.directoryList.map((item, index) => (
                      <View className='drawer-info' key={index} onClick={e => (this.jumpChapter(item.id))}>
                        <View className='drawer-info-left'>{item.name}</View>
                        {
                          item.is_vip == 1 &&
                          <Image className='drawer-info-right' src='https://video-img.fyshark.com/1683633924768dsjkmalnjdl.png'></Image>
                        }
                      </View>
                    ))
                  }
                </View>
              </View>
            </AtDrawer>
          </View>
        }
        {this.state.booksinfo.book_is_vip == 1 &&
          <View className='mine-content'>
            <View className='novel-title'>{this.state.booksinfo.book_name}</View>
            <RichText
              className='member-title'
              nodes={this.state.booksinfo.book_intro}></RichText>
            <View className='payInfo'>
              <View className='payInfo-content'>
                <View className='payInfo-title'>开通会员，继续阅读</View>
                {
                  this.state.pay_status == 0 &&
                  <View className='active' onClick={e => (this.openCode())}>
                    <Image className='active-img' src='https://video-img.fyshark.com/1685349084726icon.png' mode='widthFix'></Image>
                  </View>
                }
                <View className='purchase-list'>
                  {
                    this.state.purchaseList.map((item, index) => (
                      <View className={this.state.selectVip == index ? 'purchase-info-active' : 'purchase-info'}
                        key={index}
                        onClick={e => (this.selectVip(item, index))}
                      >
                        {
                          item.tag && item.tag.length > 0 &&
                          < View className='purchase-tips'>{item.tag}</View>
                        }
                        <View className='purchase-title'>{item.title}</View>
                        <View className='purchase-money'><View className='purchase-money-tip'>￥</View>{item.money / 100}</View>
                        <View className='purchase-oldMoney'>￥{item.coin / 100}元</View>
                        <View className='purchase-text'>
                          <View className='purchase-button'>{item.sub_title}</View>
                        </View>
                      </View>
                    ))
                  }
                </View>
                <View className='payInfo-button' onClick={e => (this.toOrder())}>
                  立即支付
                </View>
              </View>
            </View>
          </View>
        }
        {
          this.state.isOpen &&
          <View className='information'>
            <View className='information-content'>
              <View className='information-title'>
                请输入口令码
              </View>
              <View className='search'>
                <Input className='search-input' onInput={e => (this.searchCode(e))} type='text' placeholder='请输入口令码' focus />
              </View>
              <View className='information-console'>
                <View className='cancel' onClick={e => (this.cancel())}>取消</View>
                <View className='determine' onClick={e => (this.determine())}>确定</View>
              </View>
            </View>
          </View>
        }
      </View>
    )
  }
}
