import { Component } from 'react'
import { View, Text, Button, Image, scrollView, Input } from '@tarojs/components'
import * as api from '../../../../service/index'
import tool from '../../../../common/tool'
import Taro, { } from '@tarojs/taro'
import './index.less'

export default class collection extends Component {
  state = {
    title: '',
    phone: '',
    account: '',
    vip_list: [],
    vipIndex: 0,//当前选择的提现金额
    now_sum: 0,//总金额
    extract_status: 0,//是否已填写收款信息
    isOpen: false,//是否打开收款信息填写弹窗
    extract_text: '',
  }

  componentWillMount () {
    this.getExtractList()
  }
  componentDidShow () {
  }
  getExtractList () {
    api.getExtractList().then(res => {
      if (res.code == 200) {
        this.setState({
          now_sum: res.data.now_sum,
          vip_list: res.data.vip_list,
          extract_status: res.data.extract_status,
          title: res.data.alipay_name,
          phone: res.data.phone_num,
          account: res.data.alipay_account,
          extract_text: res.data.extract_text
        })
      }
    })
  }
  searchTitle (e) {
    console.log(e);
    this.setState(
      {
        title: e.detail.value
      }
    )
  }
  searchAccount (e) {
    console.log(e);
    this.setState(
      {
        account: e.detail.value
      }
    )
  }
  searchPhone (e) {
    console.log(e);
    this.setState(
      {
        phone: e.detail.value
      }
    )
  }
  cancel () {
    this.setState({
      isOpen: false
    })
  }
  determine () {
    let that = this
    switch (0) {
      case this.state.title.length:
        Taro.showToast({
          title: `请输入支付宝昵称`,
          icon: 'none',
        });
        return
      case this.state.account.length:
        Taro.showToast({
          title: `请输入支付宝账号`,
          icon: 'none',
        });
        return

      case this.state.phone.length:
        Taro.showToast({
          title: `请输入自己的手机号`,
          icon: 'none',
        });
        return
    }
    let text = `确定提现${this.state.vip_list[this.state.vipIndex].title}到支付宝吗？`
    if (this.state.vip_list[this.state.vipIndex].money == -1) {
      text = `确定将全部金额提现到支付宝吗？`
    }
    Taro.showModal({
      title: '提示',
      content: text,
      success: function (res) {
        if (res.confirm) {
          let params = {
            alipay_name: that.state.title,
            alipay_account: that.state.account,
            phone_num: that.state.phone,
            money: that.state.vip_list[that.state.vipIndex].money == -1 ? that.state.now_sum : that.state.vip_list[that.state.vipIndex].money
          }
          api.alipayExtract(params).then(i => {
            if (i.code == 200) {
              Taro.navigateBack()
            }
          })
        } else if (res.cancel) {
          console.log('用户点击取消')
        }
      }
    })
  }
  openUserInfo (item, index) {
    console.log(item);
    if (this.state.now_sum / 100 < 50) {
      Taro.showToast({
        title: `总金额小于50`,
        icon: 'none',
      });
      return
    }
    if (this.state.now_sum < item.money) {
      Taro.showToast({
        title: `总金额小于${item.money / 100}`,
        icon: 'none',
      });
      return
    }

    this.setState({
      isOpen: true,
      vipIndex: index,
    })
  }

  render () {
    return (
      <View className='mine'>
        <View className='withdrawal-top'>
          <View className='withdrawal-num'>{this.state.now_sum / 100}</View>
          <View className='withdrawal-tips'>总金额（元）</View>
        </View>
        <View className='withdrawal-info'>
          {
            this.state.extract_status == 3 &&
            <View className='withdrawal-results'>
              <View className='results-title'>提现失败</View>
              <View className='results-tips'>原因：{this.state.extract_text}</View>
            </View>
          }
          <View className='withdrawal-title'>提现</View>
          <View className='withdrawal-content'>
            {
              this.state.vip_list.map((item, index) => (
                <View className='withdrawal-info-list' key={index} onClick={e => (this.openUserInfo(item, index))}>
                  {item.money == -1 ? '全部' : `${item.money / 100}`}
                  {
                    item.money != -1 &&
                    <View className='withdrawal-info-list-unit'>元</View>
                  }
                </View>
              ))
            }
          </View>
        </View>
        <View className='tip'>
          <View className='tips-text'>1、个人提现到账时间预计在三个工作日之内。</View>
          <View className='tips-text'>2、大金额提现会有工作人员电话确认，请保持通讯正常。</View>
        </View>
        {
          this.state.isOpen &&
          <View className='information'>
            <View className='information-content'>
              <View className='information-title'>
                请填写收款信息
              </View>
              <View className='information-tips'>请仔细确认以下信息，如有错误导致打款失败平台概不负责!</View>
              <View className='search-title'>支付宝昵称：</View>
              <View className='search'>
                <Input className='search-input' onInput={e => (this.searchTitle(e))} type='text' placeholder={this.state.title.length > 0 ? this.state.title : '请输入支付宝昵称'} focus />
              </View>
              <View className='search-title'>支付宝账号：</View>
              <View className='search'>
                <Input className='search-input' onInput={e => (this.searchAccount(e))} type='text' placeholder={this.state.account.length > 0 ? this.state.account : '请输入支付宝账号'} focus />
              </View>
              <View className='search-title'>手机号：</View>
              <View className='search'>
                <Input className='search-input' onInput={e => (this.searchPhone(e))} type='text' placeholder={this.state.phone.length > 0 ? this.state.phone : '请输入自己的手机号'} focus />
              </View>
              <View className='information-console'>
                <View className='cancel' onClick={e => (this.cancel())}>取消</View>
                <View className='determine' onClick={e => (this.determine())}>确定</View>
              </View>
            </View>
          </View>
        }
      </View >
    )
  }
}
